@@ -307,6 +307,10 @@ Event::List Calendar::sortEvents( Event::List *eventList,
   case EventSortStartDate:
     alphaList = sortEvents( eventList, EventSortSummary, sortDirection );
     for ( eit = alphaList.begin(); eit != alphaList.end(); ++eit ) {
+      if ( (*eit)->dtStart().isDateOnly() ) {
+        tempList.append( *eit );
+        continue;
+      }
       sortIt = eventListSorted.begin();
       if ( sortDirection == SortDirectionAscending ) {
         while ( sortIt != eventListSorted.end() &&
@@ -321,6 +325,14 @@ Event::List Calendar::sortEvents( Event::List *eventList,
       }
       eventListSorted.insert( sortIt, *eit );
     }
+    if ( sortDirection == SortDirectionAscending ) {
+      // Prepend the list of Events without End DateTimes
+      tempList += eventListSorted;
+      eventListSorted = tempList;
+    } else {
+      // Append the list of Events without End DateTimes
+      eventListSorted += tempList;
+    }
     break;
 
   case EventSortEndDate:
@@ -523,8 +535,8 @@ Incidence *Calendar::incidence( const QString &uid )
 Incidence::List Calendar::incidencesFromSchedulingID( const QString &sid )
 {
   Incidence::List result;
-  Incidence::List incidences = rawIncidences();
-  Incidence::List::iterator it = incidences.begin();
+  const Incidence::List incidences = rawIncidences();
+  Incidence::List::const_iterator it = incidences.begin();
   for ( ; it != incidences.end(); ++it ) {
     if ( (*it)->schedulingID() == sid ) {
       result.append( *it );
@@ -535,8 +547,8 @@ Incidence::List Calendar::incidencesFromSchedulingID( const QString &sid )
 
 Incidence *Calendar::incidenceFromSchedulingID( const QString &UID )
 {
-  Incidence::List incidences = rawIncidences();
-  Incidence::List::iterator it = incidences.begin();
+  const Incidence::List incidences = rawIncidences();
+  Incidence::List::const_iterator it = incidences.begin();
   for ( ; it != incidences.end(); ++it ) {
     if ( (*it)->schedulingID() == UID ) {
       // Touchdown, and the crowd goes wild
@@ -860,8 +872,8 @@ void Calendar::removeRelations( Incidence *incidence )
     }
 
     // now go through all uids that have one entry that point to the incidence
-    for ( QStringList::Iterator uidit = relatedToUids.begin();
-          uidit != relatedToUids.end(); ++uidit ) {
+    for ( QStringList::const_iterator uidit = relatedToUids.constBegin();
+          uidit != relatedToUids.constEnd(); ++uidit ) {
       Incidence::List tempList;
       // Remove all to get access to the remaining entries
       QList<Incidence*> l = d->mOrphans.values( *uidit );
@@ -1134,9 +1146,8 @@ void Calendar::appendRecurringAlarms( Alarm::List &alarms,
               Duration toFromDuration( dt, base );
               int toFrom = toFromDuration.asDays();
               if ( a->snoozeTime().end( from ) <= to ||
-                   toFromDuration.isDaily() && toFrom % snooze == 0 ||
-                   ( toFrom / snooze + 1 ) * snooze <= toFrom + period.asDays() )
-              {
+                   ( toFromDuration.isDaily() && toFrom % snooze == 0 ) ||
+                   ( toFrom / snooze + 1 ) * snooze <= toFrom + period.asDays() ) {
                 found = true;
 #ifndef NDEBUG
                 // for debug output
