@@ -263,8 +263,10 @@ VObject *VCalFormat::eventToVTodo( const Todo *anEvent )
 
   // organizer stuff
   // @TODO: How about the common name?
-  tmpStr = "MAILTO:" + anEvent->organizer().email();
-  addPropValue( vtodo, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  if ( !anEvent->organizer().email().isEmpty() ) {
+    tmpStr = "MAILTO:" + anEvent->organizer().email();
+    addPropValue( vtodo, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  }
 
   // attendees
   if ( anEvent->attendeeCount() > 0 ) {
@@ -421,8 +423,10 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
 
   // attendee and organizer stuff
   // TODO: What to do with the common name?
-  tmpStr = "MAILTO:" + anEvent->organizer().email();
-  addPropValue( vevent, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  if ( !anEvent->organizer().email().isEmpty() ) {
+    tmpStr = "MAILTO:" + anEvent->organizer().email();
+    addPropValue( vevent, ICOrganizerProp, tmpStr.toLocal8Bit() );
+  }
 
   // TODO: Put this functionality into Attendee class
   if ( anEvent->attendeeCount() > 0 ) {
@@ -553,7 +557,7 @@ VObject *VCalFormat::eventToVEvent( const Event *anEvent )
   }
   if ( !tmpStr2.isEmpty() ) {
     tmpStr2.truncate( tmpStr2.length() - 1 );
-    addPropValue( vevent, VCExDateProp, tmpStr2.toLocal8Bit() );
+    addPropValue( vevent, VCExpDateProp, tmpStr2.toLocal8Bit() );
   }
 
   // description
@@ -1197,7 +1201,7 @@ Event *VCalFormat::VEventToEvent( VObject *vevent )
   } // repeats
 
   // recurrence exceptions
-  if ( ( vo = isAPropertyOf( vevent, VCExDateProp ) ) != 0 ) {
+  if ( ( vo = isAPropertyOf( vevent, VCExpDateProp ) ) != 0 ) {
     s = fakeCString( vObjectUStringZValue( vo ) );
     QStringList exDates = QString::fromLocal8Bit( s ).split( ',' );
     QStringList::ConstIterator it;
